All of lore.kernel.org
 help / color / mirror / Atom feed
From: Ian Kent <raven@themaw.net>
To: autofs mailing list <autofs@vger.kernel.org>
Subject: [PATCH 08/37] autofs-5.1.2 - Change .requestor to .requester for consistency
Date: Tue, 25 Oct 2016 09:18:07 +0800	[thread overview]
Message-ID: <20161025011807.7778.25316.stgit@pluto.themaw.net> (raw)
In-Reply-To: <20161025010014.7778.69274.stgit@pluto.themaw.net>

From: Tomohiro Kusumi <kusumi.tomohiro@gmail.com>

Since the name of ioctl command is AUTOFS_DEV_IOCTL_REQUESTER,
we should use .requester for consistency, assuming autofs
userspace doesn't have intention to provide these interface
for external programs or libraries which break api compatibiliy.

Also note that kernel code of autofs uses "requester".

Signed-off-by: Tomohiro Kusumi <kusumi.tomohiro@gmail.com>
---
 CHANGELOG               |    1 +
 daemon/automount.c      |    2 +-
 include/automount.h     |    4 ++--
 include/dev-ioctl-lib.h |    2 +-
 lib/dev-ioctl-lib.c     |   10 +++++-----
 lib/mounts.c            |    4 ++--
 6 files changed, 12 insertions(+), 11 deletions(-)

diff --git a/CHANGELOG b/CHANGELOG
index 96260b7..6333959 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -7,6 +7,7 @@ xx/xx/2016 autofs-5.1.3
 - Fix size arg of fgets(3).
 - fix libtirpc detection with -Wl,--as-needed.
 - Fix a typo in CREDITS.
+- Change .requestor to .requester for consistency.
 
 15/06/2016 autofs-5.1.2
 =======================
diff --git a/daemon/automount.c b/daemon/automount.c
index ad5cafd..fee93cc 100644
--- a/daemon/automount.c
+++ b/daemon/automount.c
@@ -238,7 +238,7 @@ int rmdir_path(struct autofs_point *ap, const char *path, dev_t dev)
 			crit(ap->logopt, "attempt to remove directory from a "
 			     "non-autofs filesystem!");
 			crit(ap->logopt,
-			     "requestor dev == %llu, \"%s\" owner dev == %llu",
+			     "requester dev == %llu, \"%s\" owner dev == %llu",
 			     dev, buf, st.st_dev);
 			return -1;
 		}
diff --git a/include/automount.h b/include/automount.h
index c0f5fbf..2029e3d 100644
--- a/include/automount.h
+++ b/include/automount.h
@@ -425,8 +425,8 @@ struct pending_args {
 	char name[PATH_MAX];		/* Name field of the request */
 	dev_t dev;			/* device number of mount */
 	unsigned int len;		/* Name field len */
-	uid_t uid;			/* uid of requestor */
-	gid_t gid;			/* gid of requestor */
+	uid_t uid;			/* uid of requester */
+	gid_t gid;			/* gid of requester */
 	unsigned long wait_queue_token;	/* Associated kernel wait token */
 };
 
diff --git a/include/dev-ioctl-lib.h b/include/dev-ioctl-lib.h
index b96e0dd..eb9075c 100644
--- a/include/dev-ioctl-lib.h
+++ b/include/dev-ioctl-lib.h
@@ -46,7 +46,7 @@ struct ioctl_ops {
 	int (*setpipefd)(unsigned int, int, int);
 	int (*catatonic)(unsigned int, int);
 	int (*timeout)(unsigned int, int, time_t);
-	int (*requestor)(unsigned int, int, const char *, uid_t *, gid_t *);
+	int (*requester)(unsigned int, int, const char *, uid_t *, gid_t *);
 	int (*expire)(unsigned int, int, const char *, unsigned int);
 	int (*askumount)(unsigned int, int, unsigned int *);
 	int (*ismountpoint)(unsigned int, int, const char *, unsigned int *);
diff --git a/lib/mounts.c b/lib/mounts.c
index c67548e..d3d7345 100644
--- a/lib/mounts.c
+++ b/lib/mounts.c
@@ -1602,7 +1602,7 @@ static int do_remount_direct(struct autofs_point *ap, int fd, const char *path)
 	gid_t gid;
 	int ret;
 
-	ops->requestor(ap->logopt, fd, path, &uid, &gid);
+	ops->requester(ap->logopt, fd, path, &uid, &gid);
 	if (uid != -1 && gid != -1)
 		set_tsd_user_vars(ap->logopt, uid, gid);
 
@@ -1671,7 +1671,7 @@ static int do_remount_indirect(struct autofs_point *ap, int fd, const char *path
 			}
 		}
 
-		ops->requestor(ap->logopt, fd, buf, &uid, &gid);
+		ops->requester(ap->logopt, fd, buf, &uid, &gid);
 		if (uid != -1 && gid != -1)
 			set_tsd_user_vars(ap->logopt, uid, gid);
 

diff --git a/lib/dev-ioctl-lib.c b/lib/dev-ioctl-lib.c
index 85b3272..e851923 100644
--- a/lib/dev-ioctl-lib.c
+++ b/lib/dev-ioctl-lib.c
@@ -56,7 +56,7 @@ static int dev_ioctl_send_fail(unsigned int, int, unsigned int, int);
 static int dev_ioctl_setpipefd(unsigned int, int, int);
 static int dev_ioctl_catatonic(unsigned int, int);
 static int dev_ioctl_timeout(unsigned int, int, time_t);
-static int dev_ioctl_requestor(unsigned int, int, const char *, uid_t *, gid_t *);
+static int dev_ioctl_requester(unsigned int, int, const char *, uid_t *, gid_t *);
 static int dev_ioctl_expire(unsigned int, int, const char *, unsigned int);
 static int dev_ioctl_askumount(unsigned int, int, unsigned int *);
 static int dev_ioctl_ismountpoint(unsigned int, int, const char *, unsigned int *);
@@ -85,7 +85,7 @@ static struct ioctl_ops dev_ioctl_ops = {
 	.setpipefd	= dev_ioctl_setpipefd,
 	.catatonic	= dev_ioctl_catatonic,
 	.timeout	= dev_ioctl_timeout,
-	.requestor	= dev_ioctl_requestor,
+	.requester	= dev_ioctl_requester,
 	.expire		= dev_ioctl_expire,
 	.askumount	= dev_ioctl_askumount,
 	.ismountpoint	= dev_ioctl_ismountpoint
@@ -103,7 +103,7 @@ static struct ioctl_ops ioctl_ops = {
 	.setpipefd	= NULL,
 	.catatonic	= ioctl_catatonic,
 	.timeout	= ioctl_timeout,
-	.requestor	= NULL,
+	.requester	= NULL,
 	.expire		= ioctl_expire,
 	.askumount	= ioctl_askumount,
 	.ismountpoint	= NULL
@@ -261,7 +261,7 @@ static void free_dev_ioctl_open(struct autofs_dev_ioctl *ioctl)
 
 /*
  * Allocate a parameter struct for misc device ioctl which includes
  * a path. This is used when getting the last mount requestor uid
  * and gid and when checking if a path within the autofs filesystem
  * is a mount point. We add the path to the end of the struct.
  */
@@ -607,7 +607,7 @@ static int ioctl_timeout(unsigned int logopt, int ioctlfd, time_t timeout)
  * process uid and gid (or string variations of them) for mount
  * lookups within the map entry.
  */
-static int dev_ioctl_requestor(unsigned int logopt,
+static int dev_ioctl_requester(unsigned int logopt,
 			       int ioctlfd, const char *path,
 			       uid_t *uid, gid_t *gid)
 {
@@ -261,7 +261,7 @@ static void free_dev_ioctl_open(struct autofs_dev_ioctl *ioctl)
 /*
  * Allocate a parameter struct for misc device ioctl which includes
- * a path. This is used when getting the last mount requestor uid
+ * a path. This is used when getting the last mount requester uid
  * and gid and when checking if a path within the autofs filesystem
  * is a mount point. We add the path to the end of the struct.
--
To unsubscribe from this list: send the line "unsubscribe autofs" in

  parent reply	other threads:[~2016-10-25  1:18 UTC|newest]

Thread overview: 39+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-10-25  1:17 [PATCH 00/37] Current patch queue for review Ian Kent
2016-10-25  1:17 ` [PATCH 01/37] autofs-5.1.2 - fix release date in CHANGELOG Ian Kent
2016-10-25  1:17 ` [PATCH 02/37] autofs-5.1.2 - build: check for clock_gettime in librt Ian Kent
2016-10-25  1:17 ` [PATCH 03/37] autofs-5.1.2 - Fix compiler warning in try_remount() Ian Kent
2016-10-25  1:17 ` [PATCH 04/37] autofs-5.1.2 - Drop redundant \n in logerr() Ian Kent
2016-10-25  1:17 ` [PATCH 05/37] autofs-5.1.2 - Fix size arg of fgets(3) Ian Kent
2016-10-25  1:17 ` [PATCH 06/37] autofs-5.1.2 - fix libtirpc detection with -Wl, --as-needed Ian Kent
2016-10-25  1:18 ` [PATCH 07/37] autofs-5.1.2 - Fix a typo in CREDITS Ian Kent
2016-10-25  1:18 ` Ian Kent [this message]
2016-10-25  1:18 ` [PATCH 09/37] autofs-5.1.2 - fix file map changed check Ian Kent
2016-10-25  1:18 ` [PATCH 10/37] autofs-5.1.2 - Remove unused local 2KB buffer Ian Kent
2016-10-25  1:18 ` [PATCH 11/37] autofs-5.1.2 - Fix typos in error messages Ian Kent
2016-10-25  1:18 ` [PATCH 12/37] autofs-5.1.2 - Fix fgets(3) size argument (another one) Ian Kent
2016-10-25  1:18 ` [PATCH 13/37] autofs-5.1.2 - fix short memory allocation in lookup_amd_instance() Ian Kent
2016-10-25  1:18 ` [PATCH 14/37] autofs-5.1.2 - fix count_mounts() function Ian Kent
2016-10-25  1:18 ` [PATCH 15/37] autofs-5.1.2 - configure: add cache variable for Linux proc filesystem check Ian Kent
2016-10-25  1:18 ` [PATCH 16/37] autofs-5.1.2 - Avoid local variable name shadowing another Ian Kent
2016-10-25  1:18 ` [PATCH 17/37] autofs-5.1.2 - fix typo in MOUNT_FLAG_GHOST comment Ian Kent
2016-10-25  1:19 ` [PATCH 18/37] autofs-5.1.2 - fix cachefs parse message not being logged Ian Kent
2016-10-25  1:19 ` [PATCH 19/37] autofs-5.1.2 - fix argc off by one in mount_autofs.c Ian Kent
2016-10-25  1:19 ` [PATCH 20/37] autofs-5.1.2 - fix _strncmp() usage Ian Kent
2016-10-25  1:19 ` [PATCH 21/37] autofs-5.1.1 - fix create_client() RPC client handling Ian Kent
2016-10-25  1:19 ` [PATCH 22/37] autofs-5.1.2 - update and add README for old autofs schema Ian Kent
2016-10-25  1:19 ` [PATCH 23/37] autofs-5.1.2 - wait for master map available at start Ian Kent
2016-10-25  1:19 ` [PATCH 24/37] autofs-5.1.2 - add master read wait option Ian Kent
2016-10-25  1:19 ` [PATCH 25/37] autofs-5.1.2 - work around sss startup delay Ian Kent
2016-10-25  1:19 ` [PATCH 26/37] autofs-5.1.2 - add sss master map wait config option Ian Kent
2016-10-25  1:19 ` [PATCH 27/37] autofs-5.1.2 - fix typos in README.amd-maps Ian Kent
2016-10-25  1:19 ` [PATCH 28/37] autofs-5.1.2 - add ref counting to struct map_source Ian Kent
2016-10-25  1:19 ` [PATCH 29/37] autofs-5.1.2 - add support for amd browsable option Ian Kent
2016-10-25  1:20 ` [PATCH 30/37] autofs-5.1.2 - add function conf_amd_get_map_name() Ian Kent
2016-10-25  1:20 ` [PATCH 31/37] autofs-5.1.2 - add function conf_amd_get_mount_paths() Ian Kent
2016-10-25  1:20 ` [PATCH 32/37] autofs-5.1.2 - include amd mount section mounts in master mounts list Ian Kent
2016-10-25  1:20 ` [PATCH 33/37] autofs-5.1.2 - check for conflicting amd section mounts Ian Kent
2016-10-25  1:20 ` [PATCH 34/37] autofs-5.1.2 - add function conf_get_map_options() Ian Kent
2016-10-25  1:20 ` [PATCH 35/37] autofs-5.1.2 - capture cache option and its settings during parsing Ian Kent
2016-10-25  1:20 ` [PATCH 36/37] autofs-5.1.2 - handle map_option cache for top level mounts Ian Kent
2016-10-25  1:20 ` [PATCH 37/37] autofs-5.1.2 - handle amd cache option all in amd type auto mounts Ian Kent
2016-11-04  8:53 ` [PATCH 00/37] Current patch queue for review Ian Kent

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20161025011807.7778.25316.stgit@pluto.themaw.net \
    --to=raven@themaw.net \
    --cc=autofs@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.